"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_worker_threads_1 = require("node:worker_threads");
const __1 = __importDefault(require(".."));
class Thread {
    name;
    filename;
    options;
    threadManager;
    worker;
    constructor(threadManager, name, filename, options) {
        this.name = name;
        this.filename = filename;
        this.options = options;
        this.threadManager = threadManager;
        this.worker = new node_worker_threads_1.Worker(this.filename, this.options);
    }
    emit(messageKey, ...value) {
        // check for reserved keys
        if (messageKey in __1.default.Types.ThreadReservedMessageKeys) {
            throw `Cannot use reserved messageKey ${messageKey} as it is an reserved keyword`;
        }
        this.worker.postMessage({
            messageKey,
            value,
        });
    }
    on(messageKey, cb) {
        if (messageKey === 'online') {
            this.worker.on('online', cb);
        }
        if (messageKey === 'exit') {
            this.worker.on('exit', cb);
        }
        if (messageKey === 'messageError') {
            this.worker.on('messageError', cb);
        }
        if (!(messageKey in __1.default.Types.ThreadReservedMessageKeys)) {
            this.worker.on('message', (message) => {
                if (message.messageKey === messageKey) {
                    cb(message.value);
                }
                else {
                    return;
                }
            });
        }
    }
    close(exit) {
        this.emit(__1.default.Types.BuiltInMessageKeys.Shutdown, exit);
    }
}
exports.default = Thread;
