"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_process_1 = require("node:process");
const node_worker_threads_1 = require("node:worker_threads");
const __1 = __importDefault(require("../"));
class ThreadSelf {
    parentPort;
    data;
    constructor() {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        this.parentPort = node_worker_threads_1.parentPort;
        this.data = node_worker_threads_1.workerData;
    }
    emit(messageKey, ...value) {
        // check for reserved keys
        if (messageKey in __1.default.Types.ThreadSelfReservedMessageKeys) {
            throw new Error(`Cannot use reserved messageKey ${messageKey} as it is a reserved keyword`);
        }
        this.parentPort.postMessage({
            messageKey,
            value,
        });
    }
    on(messageKey, cb) {
        if (messageKey in __1.default.Types.BuiltInMessageKeys) {
            throw new Error(`Cannot use reserved built in messageKey ${messageKey} as it is a built in reserved keyword`);
        }
        if (messageKey === 'close') {
            this.parentPort.on('close', cb);
        }
        if (messageKey === 'messageError') {
            this.parentPort.on('messageError', cb);
        }
        if (!(messageKey in __1.default.Types.ThreadSelfReservedMessageKeys)) {
            this.parentPort.on('message', (message) => {
                if (message.messageKey === messageKey) {
                    cb(message.value);
                }
                else {
                    return;
                }
            });
        }
        // build ins
        this.parentPort.on('message', (message) => {
            if (message.messageKey === 'NEEDLEJS-THREAD-SHUTDOWN') {
                (0, node_process_1.exit)(message.value[0]);
            }
        });
    }
}
exports.default = ThreadSelf;
